@@ -278,7 +278,7 @@ def main():
     try:
         window = parse_window_str(args.time_window)
     except Exception as e:
-        parser.error("Could not parse time window: {}:".format(args.time_window, e))
+        parser.error("Could not parse time window: {}: {}".format(args.time_window, e))
 
     if not window:
         window = template.get('time-window')
