@@ -85,14 +85,16 @@ class TCursors:
         label = None
         for plot, lines, diff in self.plots:
             lines[index].setValue(value)
-            lines[index].label.setText('{:g}'.format(value))
+            lines[index].label.setText(str(util.TDStr(value)))
             if not label:
                 l0 = lines[0].value()
                 l1 = lines[1].value()
                 diff_pos = (l0 + l1)/2
                 diff_val = np.abs(l1 - l0)
-                label = u'<table><tr><td rowspan="2" valign="middle">ΔT=</td><td>{:g} s</td></tr><tr><td>{:g} Hz</td></tr></table></nobr>'.format(
-                    diff_val, 1/diff_val)
+                label = u'<table><tr><td rowspan="2" valign="middle">ΔT=</td><td>{}</td></tr><tr><td>{:g} Hz</td></tr></table></nobr>'.format(
+                    str(util.TDStr(diff_val)),
+                    1/diff_val,
+                )
             diff.setValue(diff_pos)
             diff.label.setHtml(label)
 
