@@ -286,13 +286,6 @@ class DataStore(QtCore.QObject):
     def __getitem__(self, mod):
         return self.db[mod]
 
-    @property
-    def online(self):
-        thread = self.threads.get('online')
-        if thread is not None:
-            return thread.trend
-        return False
-
     def set_lookback(self, lookback):
         self.lookback = lookback
         for bd in self.db.values():
@@ -432,7 +425,7 @@ class DataStore(QtCore.QObject):
         if span > max_seconds:
             self.signal_data_retrieve_done.emit((
                 f"Requested span too large: {max_seconds} seconds max for {trend} trend",
-                self.active
+                self.active()
             ))
             return
 
@@ -533,10 +526,10 @@ class DataStore(QtCore.QObject):
             tid = '{}-{}'.format(trend, cmd)
 
         logger.debug("CMD: {} {} {} {}".format(trend, cmd, start_end, channels))
-        if self.threads.get(tid):
+        if self.active(tid):
             logger.debug("BUSY: {}".format(tid))
             return
-        if self.threads.get('online') and cmd == 'extend':
+        if self.online and cmd == 'extend':
             logger.debug("BUSY: no extend while online")
             return
 
@@ -549,10 +542,10 @@ class DataStore(QtCore.QObject):
         channels = channels or self.channels
 
         t = nds.NDSThread(tid, trend, cmd, channels, start_end)
+        self.threads[tid] = t
         t.new_data.connect(self.remote_recv)
         t.done.connect(self.remote_done)
         t.start()
-        self.threads[tid] = t
 
     @Slot('PyQt_PyObject')
     def remote_recv(self, recv):
@@ -596,30 +589,37 @@ class DataStore(QtCore.QObject):
     def remote_done(self, recv):
         logger.debug("DONE: {}".format(recv))
         tid, error = recv
-        self.threads[tid] = None
         if error:
             error = "NDS error: {}".format(error)
             logger.warning(error)
         else:
             error = ''
-        signal = (error, self.active)
+        signal = (error, self.active())
         if tid == 'online':
             self.signal_data_online_done.emit(signal)
         else:
             self.signal_data_retrieve_done.emit(signal)
 
-    @property
-    def active(self):
+    def active(self, tid=None):
+        if tid:
+            thread = self.threads.get(tid)
+            if thread:
+                return not thread.isFinished()
+            else:
+                return False
         for thread in self.threads.values():
-            if thread is not None:
+            if not thread.isFinished():
                 return True
         return False
 
+    @property
+    def online(self):
+        return self.active('online')
+
     def terminate(self):
         logger.debug("TERMINATE")
         for thread in self.threads.values():
-            if thread:
-                thread.stop()
-                # FIXME: thread terminate is causing problems on SL7
-                # thread.terminate()
-                # self.notify_done()
+            thread.stop()
+            # FIXME: thread terminate is causing problems on SL7
+            # thread.terminate()
+            # self.notify_done()
